changeset 1101:4282c86136f0

8177350: Two missed in the change from ${java.home}/lib to ${java.home}/conf Reviewed-by: lancea, mchung
author joehw
date Thu, 23 Mar 2017 13:03:13 -0700
parents c5553d4ca3b7
children 389969e18ba2
files src/java.xml/share/classes/javax/xml/stream/FactoryFinder.java src/java.xml/share/classes/javax/xml/xpath/XPathFactoryFinder.java
diffstat 2 files changed, 7 insertions(+), 7 deletions(-) [+]
line wrap: on
line diff
--- a/src/java.xml/share/classes/javax/xml/stream/FactoryFinder.java	Wed Mar 22 18:41:31 2017 +0000
+++ b/src/java.xml/share/classes/javax/xml/stream/FactoryFinder.java	Thu Mar 23 13:03:13 2017 -0700
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2005, 2016, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2005, 2017, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -270,7 +270,7 @@
                     "Failed to read factoryId '" + factoryId + "'", se);
         }
 
         // Try read $java.home/lib/stax.properties followed by
         // $java.home/conf/jaxp.properties if former not present
         String configFile = null;
         try {
@@ -278,7 +278,7 @@
                 synchronized (cacheProps) {
                     if (firstTime) {
                         configFile = ss.getSystemProperty("java.home") + File.separator +
-                            "lib" + File.separator + "stax.properties";
+                            "conf" + File.separator + "stax.properties";
                         final File fStax = new File(configFile);
                         firstTime = false;
                         if (ss.doesFileExist(fStax)) {
@@ -270,7 +270,7 @@
         }
 
-        // Try read $java.home/lib/stax.properties followed by
+        // Try read $java.home/conf/stax.properties followed by
         // $java.home/conf/jaxp.properties if former not present
         String configFile = null;
--- a/src/java.xml/share/classes/javax/xml/xpath/XPathFactoryFinder.java	Wed Mar 22 18:41:31 2017 +0000
+++ b/src/java.xml/share/classes/javax/xml/xpath/XPathFactoryFinder.java	Thu Mar 23 13:03:13 2017 -0700
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2004, 2016, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2004, 2017, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -176,9 +176,9 @@
 
         String javah = ss.getSystemProperty( "java.home" );
         String configFile = javah + File.separator +
-        "lib" + File.separator + "jaxp.properties";
+        "conf" + File.separator + "jaxp.properties";
 
         // try to read from $java.home/lib/jaxp.properties
         try {
             if(firstTime){
                 synchronized(cacheProps){
@@ -193,7 +193,7 @@
                 }
             }
             final String factoryClassName = cacheProps.getProperty(propertyName);
-            debugPrintln(()->"found " + factoryClassName + " in $java.home/jaxp.properties");
+            debugPrintln(()->"found " + factoryClassName + " in $java.home/conf/jaxp.properties");
 
             if (factoryClassName != null) {
                 xpathFactory = createInstance(factoryClassName, true);
@@ -176,9 +176,9 @@
 
-        // try to read from $java.home/lib/jaxp.properties
+        // try to read from $java.home/conf/jaxp.properties
         try {
             if(firstTime){